@@ -6,20 +6,19 @@ Provides a clean, Pythonic interface for PDF operations that closely
 mirrors the Java client structure and functionality.
 """
 
-from .client_v1 import ClientV1
 from .exceptions import (
     PdfDancerException, FontNotFoundException, ValidationException,
     HttpClientException, SessionException
 )
 from .models import (
-    ObjectRef, Position, ObjectType, Font, Color, Image, BoundingRect, Paragraph,
+    ObjectRef, Position, ObjectType, Font, Color, Image, BoundingRect, Paragraph, FormFieldRef,
     PositionMode, ShapeType, Point
 )
 from .paragraph_builder import ParagraphBuilder
 
 __version__ = "1.0.0"
 __all__ = [
-    "ClientV1",
+    "PDFDancer",
     "ParagraphBuilder",
     "ObjectRef",
     "Position",
@@ -29,6 +28,7 @@ __all__ = [
     "Image",
     "BoundingRect",
     "Paragraph",
+    "FormFieldRef",
     "PositionMode",
     "ShapeType",
     "Point",
@@ -38,3 +38,5 @@ __all__ = [
     "HttpClientException",
     "SessionException"
 ]
+
+from .pdfdancer_v1 import PDFDancer
